Function create_rust_app::auth::controller::check
source · pub fn check(_: &Auth)Expand description
/check
just a lifeline function, clients can post to this endpoint to check if the auth service is running
pub fn check(_: &Auth)/check
just a lifeline function, clients can post to this endpoint to check if the auth service is running