Function create_rust_app::auth::controller::refresh
source · pub fn refresh(
db: &Database,
refresh_token_str: Option<&str>
) -> Result<(String, String), (i32, &'static str)>Expand description
/refresh
refreshes the user session associated with the clients refresh_token cookie
Returns Result
- Ok([
AccessToken], [RefreshToken])- an access token that should be sent to the user in the response body,
- a reset token that should be sent as a secure, http-only, and same_site=strict cookie.
- Err([
StatusCode], [Message])