Struct create_rust_app::AppData
source · pub struct AppData {
pub mailer: Mailer,
pub database: Database,
pub storage: Storage,
}Expand description
Fields
mailer: Mailerwrapper for SMTP mailing server accessed by chosen web framework
see Mailer
database: Databasedb agnostic wrapper for databases accessed by chosen web framework
see Database
storage: Storagewrapper for Amazon S3 cloud file storage service accessed by chosen web framework
see Storage