Module create_rust_app::auth::controller
source · Structs
Rust struct representing the Json body of
GET requests to the …/activate endpoint
Rust struct representing the Json body of
POST requests to the /change endpoint
Rust struct representing the Json body of
POST requests to the /forgot endpoint
Rust struct representing the Json body of
POST requests to the …/login endpoint
TODO: documentation
Rust struct representing the Json body of
POST requests to the …/register endpoint
TODO: documentation
Rust struct representing the Json body of
POST requests to the /reset endpoint
TODO: documentation
Constants
Functions
/activate
/change
/check
/sessions/{id}
/sessions
/forgot
sends an email to the email in the [‘ForgotInput’] Json in the request body
that will allow the user associated with that email to change their password
/sessions
/login
/logout
If this is successful, delete the cookie storing the refresh token
/refresh
/register
reset