pub fn register(
    db: &Database,
    item: &RegisterInput,
    mailer: &Mailer
) -> Result<(), (i32, &'static str)>
/register

creates a new User with the information in item

sends an email, using mailer, to the email address in item that contains a unique link that allows the recipient to activate the account associated with that email address

Returns Result

  • Ok(())
  • Err([StatusCode], [Message])